<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>ALSA::CTL_Arg_Name</name>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="116"/>
        <source>CARD</source>
        <translation>Karte</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="117"/>
        <source>SOCKET</source>
        <translation>Socket</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="118"/>
        <source>CTL</source>
        <translation>CTL</translation>
    </message>
</context>
<context>
    <name>ALSA::CTL_Elem_IFace_Name</name>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="96"/>
        <source>CARD</source>
        <translation>Karte</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="97"/>
        <source>HWDEP</source>
        <translation>Gerätespez.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="98"/>
        <source>MIXER</source>
        <translation>Mixer</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="99"/>
        <source>PCM</source>
        <translation>PCM</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="100"/>
        <source>RAWMIDI</source>
        <translation>Rohmidi</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="101"/>
        <source>TIMER</source>
        <translation>Zeitgeber</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="102"/>
        <source>SEQUENCER</source>
        <translation>Sequencer</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="103"/>
        <location filename="../../shared/src/qsnd/mixer_hctl_info_db.cpp" line="95"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
</context>
<context>
    <name>ALSA::CTL_Elem_Type_Name</name>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="106"/>
        <source>NONE</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="107"/>
        <source>BOOLEAN</source>
        <translation>Bool</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="108"/>
        <source>INTEGER</source>
        <translation>Integer</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="109"/>
        <source>ENUMERATED</source>
        <translation>Aufzählung</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="110"/>
        <source>BYTES</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="111"/>
        <source>IEC958</source>
        <translation>IEC958</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="112"/>
        <source>INTEGER64</source>
        <translation>Integer64</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="113"/>
        <location filename="../../shared/src/qsnd/mixer_hctl_info_db.cpp" line="59"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
</context>
<context>
    <name>ALSA::Channel_Name</name>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="85"/>
        <source>Front Left</source>
        <translation>Vorne links</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="86"/>
        <source>Front Right</source>
        <translation>Vorne rechts</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="87"/>
        <source>Rear Left</source>
        <translation>Hinten links</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="88"/>
        <source>Rear Right</source>
        <translation>Hinten rechts</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="89"/>
        <source>Front Center</source>
        <translation>Vorne Mitte</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="90"/>
        <source>Woofer</source>
        <translation>Tieftöner</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="91"/>
        <source>Side Left</source>
        <translation>Seite links</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="92"/>
        <source>Side Right</source>
        <translation>Seite rechts</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="93"/>
        <source>Rear Center</source>
        <translation>Hinten Mitte</translation>
    </message>
</context>
<context>
    <name>ALSA::Elem_Name</name>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="47"/>
        <source>Master</source>
        <translation>Hauptregler</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="55"/>
        <source>Speaker</source>
        <translation>Lautsprecher</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="41"/>
        <source>Headphone</source>
        <translation>Kopfhörer</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="42"/>
        <source>Headphone LFE</source>
        <translation>Kopfhörer LFE</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="43"/>
        <source>Headphone Center</source>
        <translation>Kopfhörer Mitte</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="38"/>
        <source>Front</source>
        <translation>Vorne</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="29"/>
        <source>Auto-Mute Mode</source>
        <translation>Auto-Stumm-Modus</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="39"/>
        <source>Front Mic</source>
        <translation>Mik. Vorne</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="40"/>
        <source>Front Mic Boost</source>
        <translation>Mik. Vorne Verstärkung</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="48"/>
        <source>Mic</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="49"/>
        <source>Mic Boost</source>
        <translation>Mik. Verstärkung</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="53"/>
        <source>Phone</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="56"/>
        <source>Surround</source>
        <translation>Umgebung</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="58"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="33"/>
        <source>Center</source>
        <translation>Mitte</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="54"/>
        <source>Side</source>
        <translation>Seite</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="32"/>
        <source>Capture</source>
        <translation>Aufnahme</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="31"/>
        <source>Beep</source>
        <translation>Signalton</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="52"/>
        <source>PC Speaker</source>
        <translation>PC Lautsprecher</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="30"/>
        <source>Bass</source>
        <translation>Bässe</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="57"/>
        <source>Treble</source>
        <translation>Höhen</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="34"/>
        <source>Channel Mode</source>
        <translation>Kanal Modus</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="28"/>
        <source>Auto Gain Control</source>
        <translation>Autom. Verst.-Regelung</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="51"/>
        <source>Mic Select</source>
        <translation>Mikrofonwahl</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="45"/>
        <source>Internal Mic</source>
        <translation>Internes Mik.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="46"/>
        <source>Int Mic</source>
        <translation>Internes Mik.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="36"/>
        <source>External Mic</source>
        <translation>Externes Mik.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="37"/>
        <source>Ext Mic</source>
        <translation>Externes Mik.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="50"/>
        <source>Mic Boost (+20dB)</source>
        <translation>Mik. Verst. (+20dB)</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="35"/>
        <source>External Amplifier</source>
        <translation>Externer Verstärker</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="44"/>
        <source>Input Source</source>
        <translation>Eingangsquelle</translation>
    </message>
</context>
<context>
    <name>ALSA::Enum_Value</name>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="64"/>
        <source>1ch</source>
        <translation>1 Kan.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="65"/>
        <source>2ch</source>
        <translation>2 Kan.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="66"/>
        <source>3ch</source>
        <translation>3 Kan.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="67"/>
        <source>4ch</source>
        <translation>4 Kan.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="68"/>
        <source>5ch</source>
        <translation>5 Kan.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="69"/>
        <source>6ch</source>
        <translation>6 Kan.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="70"/>
        <source>7ch</source>
        <translation>7 Kan.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="71"/>
        <source>8ch</source>
        <translation>8 Kan.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="74"/>
        <source>Internal Mic</source>
        <translation>Internes Mik.</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="75"/>
        <source>Mic</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="73"/>
        <source>Front Mic</source>
        <translation>Mik. Vorne</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="61"/>
        <source>Enabled</source>
        <translation>Aktiviert</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="62"/>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="76"/>
        <source>Mic1</source>
        <translation>Mik. 1</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="77"/>
        <source>Mic2</source>
        <translation>Mik. 2</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="78"/>
        <source>Mic3</source>
        <translation>Mik. 3</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="79"/>
        <source>Mic4</source>
        <translation>Mik. 4</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="81"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/alsa_i18n.hpp" line="82"/>
        <source>Phone</source>
        <translation>Telefon</translation>
    </message>
</context>
<context>
    <name>ALSA::Flags</name>
    <message>
        <location filename="../../shared/src/qsnd/mixer_hctl_info_db.cpp" line="101"/>
        <source>not readable</source>
        <translation>nicht lesbar</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/mixer_hctl_info_db.cpp" line="103"/>
        <source>readable</source>
        <translation>lesbar</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/mixer_hctl_info_db.cpp" line="109"/>
        <source>not writable</source>
        <translation>nicht schreibbar</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/mixer_hctl_info_db.cpp" line="111"/>
        <source>writable</source>
        <translation>schreibbar</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/mixer_hctl_info_db.cpp" line="117"/>
        <source>not volatile</source>
        <translation>nicht volatil</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/mixer_hctl_info_db.cpp" line="119"/>
        <source>volatile</source>
        <translation>volatil</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/mixer_hctl_info_db.cpp" line="125"/>
        <source>not active</source>
        <translation>nicht aktiv</translation>
    </message>
    <message>
        <location filename="../../shared/src/qsnd/mixer_hctl_info_db.cpp" line="127"/>
        <source>active</source>
        <translation>aktiv</translation>
    </message>
</context>
<context>
    <name>MWdg::Inputs_Setup</name>
    <message>
        <location filename="../../shared/src/mwdg/inputs_setup.cpp" line="35"/>
        <source>s</source>
        <extracomment>&quot;s&quot; is an abbreviation for &quot;split&quot; or &quot;separate&quot;. Something like &quot;j&quot; for &quot;joined&quot; or &quot;c&quot; for &quot;channel&quot; may be appropriate, too.</extracomment>
        <translatorcomment>Trennen</translatorcomment>
        <translation>t</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/inputs_setup.cpp" line="39"/>
        <source>l</source>
        <extracomment>&quot;l&quot; is an abbreviation for &quot;level&quot;</extracomment>
        <translatorcomment>Nivellieren</translatorcomment>
        <translation>n</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/inputs_setup.cpp" line="43"/>
        <source>m</source>
        <extracomment>&quot;m&quot; is an abbreviation for &quot;mute&quot;</extracomment>
        <translatorcomment>Stumm</translatorcomment>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/inputs_setup.cpp" line="47"/>
        <source>p</source>
        <extracomment>&quot;p&quot; is an abbreviation for &quot;playback&quot;</extracomment>
        <translatorcomment>Wiedergabe</translatorcomment>
        <translation>w</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/inputs_setup.cpp" line="51"/>
        <source>c</source>
        <extracomment>&quot;c&quot; is an abbreviation for &quot;capture&quot; or &quot;record&quot;</extracomment>
        <translatorcomment>Aufnahme</translatorcomment>
        <translation>a</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/inputs_setup.cpp" line="58"/>
        <source>Split &amp;channels</source>
        <extracomment>Used in the context menu (slider/switch right click menu)</extracomment>
        <translation>&amp;Kanäle trennen</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/inputs_setup.cpp" line="62"/>
        <source>Join &amp;channels</source>
        <extracomment>Used in the context menu (slider/switch right click menu)</extracomment>
        <translation>&amp;Kanäle verbinden</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/inputs_setup.cpp" line="66"/>
        <source>&amp;Level channels</source>
        <extracomment>Used in the context menu (slider/switch right click menu)</extracomment>
        <translation>Kanäle &amp;nivellieren</translation>
    </message>
</context>
<context>
    <name>MWdg::Mixer_HCTL</name>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="44"/>
        <source>Element name</source>
        <translation>Elementname</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="48"/>
        <source>Joined</source>
        <translation>Verbunden</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="49"/>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="121"/>
        <source>Element index</source>
        <translation>Elementindex</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="50"/>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="53"/>
        <source>Channel %1</source>
        <translation>Kanal %1</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="52"/>
        <source>Ch. %1</source>
        <translation>Kan. %1</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="57"/>
        <source>Index: %1</source>
        <translation>Index: %1</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="58"/>
        <source>Channel: %2</source>
        <translation>Kanal: %2</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="114"/>
        <source>Index:</source>
        <translation>Index:</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="115"/>
        <source>Device:</source>
        <translation>Gerät:</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="116"/>
        <source>Flags:</source>
        <translation>Flaggen:</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="117"/>
        <source>Channels:</source>
        <translation>Kanäle:</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="118"/>
        <source>Num. id:</source>
        <translation>Num. id:</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="122"/>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="138"/>
        <source>Device</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="123"/>
        <source>Flags</source>
        <translation>Flaggen</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="124"/>
        <source>Channel count</source>
        <translation>Kanalanzahl</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="125"/>
        <source>Numeric Id</source>
        <translation>Numerische Id</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="139"/>
        <source>Subdevice</source>
        <translation>Untergerät</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl.cpp" line="337"/>
        <source>No element selected</source>
        <translation>Kein Element ausgewählt</translation>
    </message>
</context>
<context>
    <name>MWdg::Mixer_HCTL_Edit_Int</name>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_edit_int.cpp" line="52"/>
        <source>minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_edit_int.cpp" line="52"/>
        <source>maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_edit_int.cpp" line="53"/>
        <source>Integer range:</source>
        <translation>Integerbereich:</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_edit_int.cpp" line="54"/>
        <source>Decibel range:</source>
        <translation>Dezibelbereich:</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_edit_int.cpp" line="143"/>
        <source>Channel %1</source>
        <translation>Kanal %1</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_edit_int.cpp" line="144"/>
        <source>Index %1</source>
        <translation>Index %1</translation>
    </message>
</context>
<context>
    <name>MWdg::Mixer_HCTL_Edit_Unsupported</name>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_edit_unsupported.cpp" line="35"/>
        <source>Elements of the type %1 are not supported</source>
        <translation>Elemente vom Typ %1 werden nicht unterstützt</translation>
    </message>
</context>
<context>
    <name>MWdg::Mixer_HCTL_Int_Proxy_Column</name>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_int_proxy_column.cpp" line="25"/>
        <source>%1 dB</source>
        <extracomment>Decibel value string template</extracomment>
        <translation>%1 dB</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_int_proxy_column.cpp" line="27"/>
        <source>%1 %</source>
        <extracomment>Percent value string template</extracomment>
        <translation>%1 %</translation>
    </message>
</context>
<context>
    <name>MWdg::Mixer_HCTL_Table_Model</name>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="35"/>
        <source>%1,%2</source>
        <translation>%1,%2</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="43"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="44"/>
        <source>Element name</source>
        <translation>Elementname</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="47"/>
        <source>Idx</source>
        <extracomment>Idx - abbreviation for Index</extracomment>
        <translation>Idx</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="48"/>
        <source>Element index</source>
        <translation>Elementindex</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="50"/>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="51"/>
        <source>Device</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="53"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="54"/>
        <source>Element type</source>
        <translation>Elementtyp</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="57"/>
        <source>Ch.</source>
        <extracomment>Ch. - abbreviation for Channel</extracomment>
        <translation>Kan.</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="58"/>
        <source>Channel count</source>
        <translation>Kanalanzahl</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="60"/>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="61"/>
        <source>Flags</source>
        <translation>Flaggen</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="63"/>
        <source>Id</source>
        <translation>Id</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/mwdg/mixer_hctl_table_model.cpp" line="64"/>
        <source>Numeric Id</source>
        <translation>Numerische Id</translation>
    </message>
</context>
<context>
    <name>MWdg::Mixer_Sliders</name>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_sliders.cpp" line="81"/>
        <source>&amp;Mute</source>
        <translation>Aus&amp;schalten</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_sliders.cpp" line="82"/>
        <source>&amp;Mute all</source>
        <translation>Alle aus&amp;schalten</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_sliders.cpp" line="83"/>
        <source>Un&amp;mute</source>
        <translation>Ein&amp;schalten</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_sliders.cpp" line="84"/>
        <source>Un&amp;mute all</source>
        <translation>Alle Ein&amp;schalten</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_sliders.cpp" line="85"/>
        <source>Toggle &amp;mutes</source>
        <translation>Um&amp;schalten</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_sliders.cpp" line="112"/>
        <source>Playback slider</source>
        <translation>Wiedergabeschieber</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_sliders.cpp" line="113"/>
        <source>Capture slider</source>
        <translation>Aufnahmeschieber</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_sliders.cpp" line="114"/>
        <source>Playback switch</source>
        <translation>Wiedergabeschalter</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_sliders.cpp" line="115"/>
        <source>Capture switch</source>
        <translation>Aufnahmeschalter</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_sliders.cpp" line="308"/>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
</context>
<context>
    <name>MWdg::Mixer_Sliders_Proxies_Column</name>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_sliders_proxies_column.cpp" line="27"/>
        <source>%1 dB</source>
        <translation>%1 dB</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_sliders_proxies_column.cpp" line="28"/>
        <source>%1 %</source>
        <translation>%1 %</translation>
    </message>
</context>
<context>
    <name>MWdg::Mixer_Switches</name>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_switches.cpp" line="289"/>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_switches.cpp" line="304"/>
        <source>Playback selection</source>
        <translation>Wiedergabeauswahl</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_switches.cpp" line="306"/>
        <source>Playback switch</source>
        <translation>Wiedergabeschalter</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_switches.cpp" line="310"/>
        <source>Capture selection</source>
        <translation>Aufnahmeauswahl</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/mwdg/mixer_switches.cpp" line="312"/>
        <source>Capture switch</source>
        <translation>Aufnahmeschalter</translation>
    </message>
</context>
<context>
    <name>MWdg::Slider_Status_Widget</name>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="37"/>
        <source>Slider value</source>
        <translation>Reglerwert</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="46"/>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="49"/>
        <source>Max.</source>
        <translation>Max.</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="50"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="53"/>
        <source>Min.</source>
        <translation>Min.</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="55"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="61"/>
        <source>Volume</source>
        <translation>Lautstärke</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="67"/>
        <source>Current volume</source>
        <translation>Aktuelle Lautstärke</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="73"/>
        <source>Volume maximum</source>
        <translation>Lautstärken-Maximum</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="78"/>
        <source>Volume minimum</source>
        <translation>Lautstärken-Minimum</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="86"/>
        <source>Decibel</source>
        <translation>Dezibel</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="92"/>
        <source>Current Decibel value</source>
        <translation>Aktueller Dezibel-Wert</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="100"/>
        <source>Decibel maximum</source>
        <translation>Dezibel-Maximum</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="105"/>
        <source>Decibel minimum</source>
        <translation>Dezibel-Minimum</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="111"/>
        <source>Element name</source>
        <translation>Elementname</translation>
    </message>
    <message>
        <location filename="../../shared/src/mwdg/slider_status_widget.cpp" line="351"/>
        <source>Close slider value display</source>
        <translation>Reglerwertanzeige schließen</translation>
    </message>
</context>
<context>
    <name>Main_Window</name>
    <message>
        <location filename="../../qashctl/src/main_window.cpp" line="42"/>
        <location filename="../../qasmixer/src/main_window.cpp" line="41"/>
        <source>&amp;Fullscreen mode</source>
        <translation>Voll&amp;bildmodus</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/main_window.cpp" line="43"/>
        <location filename="../../qasmixer/src/main_window.cpp" line="42"/>
        <source>Exit &amp;fullscreen mode</source>
        <translation>Voll&amp;bildmodus verlassen</translation>
    </message>
    <message>
        <location filename="../../qasconfig/src/main_window.cpp" line="129"/>
        <location filename="../../qashctl/src/main_window.cpp" line="153"/>
        <location filename="../../qasmixer/src/main_window.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/main_window.cpp" line="68"/>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/main_window.cpp" line="69"/>
        <source>Ctrl+s</source>
        <translation>Ctrl+e</translation>
    </message>
    <message>
        <location filename="../../qasconfig/src/main_window.cpp" line="134"/>
        <location filename="../../qashctl/src/main_window.cpp" line="169"/>
        <location filename="../../qasmixer/src/main_window.cpp" line="73"/>
        <source>&amp;Refresh</source>
        <translation>Auff&amp;rischen</translation>
    </message>
    <message>
        <location filename="../../qashctl/src/main_window.cpp" line="159"/>
        <location filename="../../qasmixer/src/main_window.cpp" line="79"/>
        <source>Show &amp;device selection</source>
        <translation>&amp;Geräteauswahl anzeigen</translation>
    </message>
    <message>
        <location filename="../../qasconfig/src/main_window.cpp" line="139"/>
        <location filename="../../qashctl/src/main_window.cpp" line="174"/>
        <location filename="../../qasmixer/src/main_window.cpp" line="88"/>
        <source>&amp;Info</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="../../qasconfig/src/main_window.cpp" line="145"/>
        <location filename="../../qashctl/src/main_window.cpp" line="180"/>
        <location filename="../../qasmixer/src/main_window.cpp" line="95"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="../../qasconfig/src/main_window.cpp" line="151"/>
        <location filename="../../qashctl/src/main_window.cpp" line="186"/>
        <location filename="../../qasmixer/src/main_window.cpp" line="101"/>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <location filename="../../qasconfig/src/main_window.cpp" line="157"/>
        <location filename="../../qashctl/src/main_window.cpp" line="195"/>
        <location filename="../../qasmixer/src/main_window.cpp" line="108"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
</context>
<context>
    <name>QSnd::Alsa_Config_Model</name>
    <message>
        <location filename="../../qasconfig/src/qsnd/alsa_config_model.cpp" line="255"/>
        <source>Key</source>
        <translation>Schlüssel</translation>
    </message>
    <message>
        <location filename="../../qasconfig/src/qsnd/alsa_config_model.cpp" line="257"/>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
</context>
<context>
    <name>QSnd::Mixer_HCTL</name>
    <message>
        <location filename="../../shared/src/qsnd/mixer_hctl.cpp" line="110"/>
        <source>Empty device name</source>
        <translation>Gerätename ist leer</translation>
    </message>
</context>
<context>
    <name>QSnd::Mixer_Simple</name>
    <message>
        <location filename="../../shared/src/qsnd/mixer_simple.cpp" line="124"/>
        <source>Empty device name</source>
        <translation>Gerätename ist leer</translation>
    </message>
</context>
<context>
    <name>Tray_Mixer_Balloon</name>
    <message>
        <location filename="../../qasmixer/src/tray_mixer_balloon.cpp" line="34"/>
        <source>Volume is at %1%</source>
        <translation>Lautstärke ist bei %1%</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/tray_mixer_balloon.cpp" line="40"/>
        <source>Show mixer</source>
        <translation>Mixer anzeigen</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/tray_mixer_balloon.cpp" line="67"/>
        <source>Volume muted</source>
        <translation>Stummgeschaltet</translation>
    </message>
</context>
<context>
    <name>Tray_Mixer_Icon</name>
    <message>
        <location filename="../../qasmixer/src/tray_mixer_icon.cpp" line="34"/>
        <source>&amp;Show mixer</source>
        <translation>Mixer &amp;anzeigen</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/tray_mixer_icon.cpp" line="35"/>
        <source>Ctrl+s</source>
        <translation>Ctrl+s</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/tray_mixer_icon.cpp" line="40"/>
        <source>&amp;Close %1</source>
        <extracomment>%1 will be replaced with the program title</extracomment>
        <translation>%1 &amp;beenden</translation>
    </message>
</context>
<context>
    <name>Views::Alsa_Config_View</name>
    <message>
        <location filename="../../qasconfig/src/views/alsa_config_view.cpp" line="37"/>
        <source>ALSA configuration</source>
        <translation>ALSA-Konfiguration</translation>
    </message>
    <message>
        <location filename="../../qasconfig/src/views/alsa_config_view.cpp" line="41"/>
        <source>&amp;Expand</source>
        <translation>&amp;Ausklappen</translation>
    </message>
    <message>
        <location filename="../../qasconfig/src/views/alsa_config_view.cpp" line="42"/>
        <source>Co&amp;llapse</source>
        <translation>&amp;Einklappen</translation>
    </message>
    <message>
        <location filename="../../qasconfig/src/views/alsa_config_view.cpp" line="43"/>
        <source>&amp;Sort</source>
        <translation>&amp;Sortieren</translation>
    </message>
    <message>
        <location filename="../../qasconfig/src/views/alsa_config_view.cpp" line="46"/>
        <source>Depth:</source>
        <translation>Tiefe:</translation>
    </message>
</context>
<context>
    <name>Views::Basic_Dialog</name>
    <message>
        <location filename="../../shared/src/views/basic_dialog.cpp" line="93"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
</context>
<context>
    <name>Views::Device_Selection_View</name>
    <message>
        <location filename="../../shared/src/views/dev_select_view.cpp" line="51"/>
        <source>&amp;Close device selection</source>
        <translation>Geräteauswahl &amp;schließen</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/dev_select_view.cpp" line="79"/>
        <source>Mixer device</source>
        <translation>Mixergerät</translation>
    </message>
</context>
<context>
    <name>Views::Info_Dialog</name>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="38"/>
        <source>Info</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="60"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="72"/>
        <source>Internet</source>
        <translation>Im Internet</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="75"/>
        <source>Home page</source>
        <translation>Hauptseite</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="79"/>
        <source>Project page</source>
        <translation>Projektseite</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="109"/>
        <source>Developers</source>
        <translation>Entwickler</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="118"/>
        <source>Translators</source>
        <translation>Übersetzer</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="175"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="176"/>
        <source>People</source>
        <translation>Leute</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="177"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="64"/>
        <source>%1 is a collection of desktop applications for the Linux sound system %2.</source>
        <translation>%1 ist eine Sammlung von Schreibtischanwendungen für die Linux-Klang-Architektur %2.</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="113"/>
        <source>Contributors</source>
        <translation>Mitwirkende</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/info_dialog.cpp" line="154"/>
        <source>The license file %1 is not available.</source>
        <translation>Die Lizenzdatei %1 ist nicht verfügbar.</translation>
    </message>
</context>
<context>
    <name>Views::Message_Widget</name>
    <message>
        <location filename="../../shared/src/views/message_widget.cpp" line="42"/>
        <source>Mixer device couldn&apos;t be opened</source>
        <translation>Das Gerät konnte nicht geöffnet werden</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/message_widget.cpp" line="43"/>
        <source>No device selected</source>
        <translation>Kein Gerät ausgewählt</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/message_widget.cpp" line="83"/>
        <source>Function</source>
        <translation>Funktion</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/message_widget.cpp" line="84"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../../shared/src/views/message_widget.cpp" line="85"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
<context>
    <name>Views::Mixer_Simple</name>
    <message>
        <location filename="../../qasmixer/src/views/mixer_simple.cpp" line="52"/>
        <source>Show playback</source>
        <translation>Wiedergabe anzeigen</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/mixer_simple.cpp" line="53"/>
        <source>Show capture</source>
        <translation>Aufnahme anzeigen</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/mixer_simple.cpp" line="54"/>
        <source>Show playback elements</source>
        <translation>Wiedergabe-Elemente anzeigen</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/mixer_simple.cpp" line="55"/>
        <source>Show capture elements</source>
        <translation>Aufnahme-Elemente anzeigen</translation>
    </message>
</context>
<context>
    <name>Views::Settings_Dialog</name>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="41"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="124"/>
        <source>Startup</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="132"/>
        <source>Sliders</source>
        <translation>Schieberegler</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="156"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="215"/>
        <source>Input</source>
        <translation>Eingabe</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="349"/>
        <source>System tray</source>
        <translation>Systemleiste</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="71"/>
        <source>Startup mixer device</source>
        <translation>Mixergerät beim Start</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="76"/>
        <source>From last session</source>
        <translation>Von letzter Sitzung</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="135"/>
        <source>Show slider value labels</source>
        <translation>Reglerwerte anzeigen</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="164"/>
        <source>Mouse wheel</source>
        <translation>Mausrad</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="167"/>
        <source>Number of turns for a slider change from 0% to 100%</source>
        <translation>Umdrehungen für eine Schieberänderung von 0% auf 100%</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="222"/>
        <source>Show tray icon</source>
        <translation>Symbol anzeigen</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="223"/>
        <source>Close to tray</source>
        <translation>In Systemleiste schließen</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="233"/>
        <source>System tray usage</source>
        <translation>Systemleistennutzung</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="243"/>
        <source>Notification balloon</source>
        <translation>Benachrichtigungsballon</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="246"/>
        <source>Show balloon on a volume change</source>
        <translation>Ballon bei einer Lautstärkenänderung anzeigen</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="254"/>
        <source>Balloon lifetime</source>
        <translation>Ballon-Lebensdauer</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="257"/>
        <source>ms</source>
        <extracomment>ms - abbreviation for milliseconds</extracomment>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="289"/>
        <source>Mini mixer device</source>
        <translation>Minimixergerät</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="75"/>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="291"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="292"/>
        <source>Current (same as in main mixer window)</source>
        <translation>Aktuell (das Gleiche wie im Mixerfenster)</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="77"/>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="293"/>
        <source>User defined</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="87"/>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="303"/>
        <source>User device:</source>
        <translation>Benutzergerät:</translation>
    </message>
    <message>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="88"/>
        <location filename="../../qasmixer/src/views/settings_dialog.cpp" line="304"/>
        <source>e.g. hw:0</source>
        <translation>z.B. hw:0</translation>
    </message>
</context>
</TS>
